==> borgstats-0.0.3-py3-none-any.whl: borgstats/borgstats.py <==
import json
import subprocess
import datetime
import time

import psycopg2
from psycopg2.extras import Json
import click
import humanize
from rich.console import Console
from rich.table import Table, Column
from rich import inspect, box
from rich.pretty import pprint


@click.command()
@click.option('-a', '--archive', default=str(datetime.date.today()), help='Substring archive match')
@click.option('-n', '--noop', is_flag=True, default=False, help="Don't actually do anything")
@click.option('-l', '--last', help='Look at <last> number of archives')
@click.option('-r', '--repo', help='Specific repo')
def main(archive, noop, last, repo):
    console = Console()
    if not noop:
        conn = psycopg2.connect('dbname=borg user=borg host=db password=somepassword')
        cur = conn.cursor()

    # cmd = subprocess.run('/root/venv/borgmatic-master/bin/borgmatic -c /etc/borgmatic/config.yaml info --glob-archives *{}* --json'.format(archive).split(), capture_output=True, check=True)
    borgmatic_command = 'borgmatic info --json'
    borgmatic_command += f' --repo {repo}' if repo else ''
    borgmatic_command += f' --last {last}' if last else ''
    with console.status('Running borgmatic...', spinner='dots10'):
        cmd = subprocess.run(borgmatic_command.split(), capture_output=True, check=True)
    try:
        j = json.loads(cmd.stdout.decode('utf-8'))
        #        pprint(j)
        #        z = j[0].copy()
        #        del z['archives']

        #        for x in j[0]['archives']:
        #            temp = z.copy()
        #            temp.update({'archives': [x]})
        #            if not noop:
        #                cur.execute('INSERT INTO stats (data) VALUES (%s)', [Json(temp)])
        #            pprint(temp)

        table = Table(
            'Name',
            'Duration',
            'Start',
            'End',
            Column(header='Dedupe size', justify='right'),
            title='Backups',
            header_style='on grey19',
            box=box.MINIMAL_HEAVY_HEAD,
            title_style='reverse',
        )
        for result in j:
            for archive in result['archives']:
                if archive:
                    table.add_row(
                        archive['name'],
                        time.strftime('%H:%M:%S', time.gmtime(archive['duration'])),
                        archive['start'],
                        archive['end'],
                        humanize.naturalsize(archive['stats']['deduplicated_size']),
                    )

        console.print(table)

        if not noop:
            conn.commit()
            cur.close()
            conn.close()

    except json.decoder.JSONDecodeError as e:
        print(f'Something is wrong with the JSON returned: {e}')
        print(f'This is the returned subprocess object: {cmd}')


if __name__ == '__main__':
    main()

==> borgstats-0.0.6-py3-none-any.whl: borgstats/borgstats.py <==
import json
import subprocess
import datetime
import sys
import time

# import psycopg2
# from psycopg2.extras import Json
import click
import humanize
from rich.console import Console
from rich.table import Table, Column
from rich import inspect, box
from rich.pretty import pprint


@click.command()
@click.option('-a', '--archive', default=str(datetime.date.today()), help='Substring archive match')
@click.option('-n', '--noop', is_flag=True, default=False, help="Don't actually do anything")
@click.option('-l', '--last', help='Look at <last> number of archives')
@click.option('-r', '--repo', help='Specific repo')
def main(archive, noop, last, repo):
    console = Console()
    # if not noop:
    #     conn = psycopg2.connect('dbname=borg user=borg host=db password=somepassword')
    #     cur = conn.cursor()

    # cmd = subprocess.run('/root/venv/borgmatic-master/bin/borgmatic -c /etc/borgmatic/config.yaml info --glob-archives *{}* --json'.format(archive).split(), capture_output=True, check=True)
    borgmatic_command = 'borgmatic info --json'
    borgmatic_command += f' --repo {repo}' if repo else ''
    borgmatic_command += f' --last {last}' if last else ''
    with console.status('Running borgmatic...', spinner='dots10'):
        try:
            cmd = subprocess.run(borgmatic_command.split(), capture_output=True, check=True)
        except subprocess.CalledProcessError as e:
            print(f'Error running borgmatic: {e.output}')
            sys.exit(1)
    try:
        j = json.loads(cmd.stdout.decode('utf-8'))
        #        pprint(j)
        #        z = j[0].copy()
        #        del z['archives']

        #        for x in j[0]['archives']:
        #            temp = z.copy()
        #            temp.update({'archives': [x]})
        #            if not noop:
        #                cur.execute('INSERT INTO stats (data) VALUES (%s)', [Json(temp)])
        #            pprint(temp)

        if not j[0]['archives']:
            print('No archives in repo.')
            return

        table = Table(
            'Name',
            'Duration',
            'Start',
            'End',
            Column(header='Dedupe size', justify='right'),
            title='Backups',
            header_style='on grey19',
            box=box.MINIMAL_HEAVY_HEAD,
            title_style='reverse',
        )
        for result in j:
            for archive in result['archives']:
                if archive:
                    table.add_row(
                        archive['name'],
                        time.strftime('%H:%M:%S', time.gmtime(archive['duration'])),
                        archive['start'],
                        archive['end'],
                        humanize.naturalsize(archive['stats']['deduplicated_size']),
                    )

        console.print(table)

        # if not noop:
        #     conn.commit()
        #     cur.close()
        #     conn.close()

    except json.decoder.JSONDecodeError as e:
        print(f'Something is wrong with the JSON returned: {e}')
        print(f'This is the returned subprocess object: {cmd}')


if __name__ == '__main__':
    main()
